@@ -27,14 +27,14 @@ from setproctitle import getproctitle
 getproctitle()  # 42
 
 if sys.flags.dev_mode and not (
-    len(sys.warnoptions) > 1
-    or "PYTHONWARNINGS" in os.environ
-    or " -W" in " ".join(sys.orig_argv)
+    "PYTHONWARNINGS" in os.environ or " -W" in " ".join(sys.orig_argv)
 ):
+    warnings.simplefilter("error", SyntaxWarning)
+    warnings.simplefilter("error", RuntimeWarning)
     warnings.simplefilter("error", EncodingWarning)
     warnings.simplefilter("error", DeprecationWarning)
 warnings.filterwarnings("ignore", module="defusedxml")
-warnings.filterwarnings("ignore", module="dill._dill")
+warnings.filterwarnings("ignore", module="dill._dill", category=EncodingWarning)
 
 
 from . import patches
